/********************* rexx ****************************************/
/*     (c)  Copyright   Roger Lacroix  1993                         |
|                                                                   |
|  Designed, developed and programmed by Roger Lacroix              |
+-------------------------------------------------------------------+
|                     SETUP.CMD                                     |
|                                                                   |
|   This program constructs the data file for XMIT.CMD              |
|                                                                   |
|   Input Parameters:  NONE                                         |
|   Output Parameters: NONE                                         |
|                                                                   |
|   Input File:  none                                               |
|   Output File: username.DTA                                       |
|                                                                   |
|   Objective of this SETUP.CMD:                                    |
|   1. Verify that the user has a username,                         |
|   2. Ask the user if Y:\ is O.K. for work directory,              |
|   3. Ask how many LU's does the user have,                        |
|   4. Get most used LU (i.e. default LU),                          |
|   5. Get host user id.                                            |
|   6. Ask the user if they want a hardcopy of the docs             |
|   7. Construct username.DTA in S:\XMIT\USER                       |
|                                                                   |
+-------------------------------------------------------------------+
| Subroutines (and functions) and their uses:                       |
|                                                                   |
|  GET_USER_INFO:                                                   |
|     Confirmation on username.                                     |
|                                                                   |
|  GET_WORK_DIR:                                                    |
|     Ask the user which sub-directory do they use most offen.      |
|                                                                   |
|  GET_HOWMANY_LU:                                                  |
|     Ask the user how many LU do they have.                        |
|                                                                   |
|  GETLU:                                                           |
|     Ask the user which LU will be used during this transmission.  |
|                                                                   |
|  GET_USER_ID:                                                     |
|     Get the user's host userid.                                   |
|                                                                   |
|  GET_DOC_PRINT:                                                   |
|     Ask the user if they mould like the documentation file        |
|     to be printed.                                                |
|                                                                   |
|  WRITE_DATAFILE:                                                  |
|     Write new user parameters (default values & MEMORIZED items.) |
|                                                                   |
|  COPY_DOC:                                                        |
|     Print the documentation if the user has answered YES.         |
|                                                                   |
|  COMPLETE:                                                        |
|     Tell the user that the setup program has finished.            |
|                                                                   |
|  OUT_ERROR:                                                       |
|     Output an error message to the screen.                        |
|                                                                   |
|  PANEL:                                                           |
|     Display regular panel to the user asking for input.           |
|                                                                   |
|  VALID_CHAR:                                                      |
|     Validate characters in either the DSN or filename & filetype. |
|                                                                   |
|  TABLE:                                                           |
|     Initialize regular messages and error messages.               |
|                                                                   |
|  MUSIC:                                                           |
|     Play a little music.                                          |
|                                                                   |
+-------------------------------------------------------------------+*/
/*+-----------------------+
  | Initialize variables  |
  +-----------------------+*/
env = 'OS2ENVIRONMENT'
username =  VALUE(USERNAME,,env)
username =  STRIP(username)
fn_user_data = 'D:\XMIT\USER\'username'.DTA'
fn_worksub = 'C:\'
defaultlu = "A"
totallu = 12
luletter = 'A B C D E F G H I J K L'
CALL TABLE
CALL MUSIC
/*+-------------------------------------+
  | don't let the user see the commands |
  +-------------------------------------+*/
'@ECHO OFF'
/*+------------+
  |  Mainline  |
  +------------+*/
rcode = 4
DO WHILE (rcode \= 0)
   CALL GET_USER_INFO
   CALL GET_WORK_DIR
   CALL GET_HOWMANY_LU
   CALL GETLU
   CALL GET_USER_ID
   CALL GET_DOC_PRINT
   CALL WRITE_DATAFILE
   CALL COPY_DOC
   CALL COMPLETE
   rcode = 0
END
RETURN

/*+-----------------------------------------+
  | Subroutine to get username information. |
  +-----------------------------------------+*/
GET_USER_INFO:

info = ''
header = 'Y'
DO WHILE info = ''
   /*+-------------------------------------------------+
     | Display panel to for username                   |
     +-------------------------------------------------+*/
   CALL PANEL 3,STRIP(LEFT(username,8)),' ',msg.1
   header = 'Y'
   PULL info
   info = STRIP(info)
   PARSE UPPER VAR info info                     /* upper case */
   SELECT
   WHEN SUBSTR(info,1,1) = 'Y'  THEN
        NOP
   WHEN SUBSTR(info,1,1) = 'N' THEN DO
        SAY 'Add "SET USERNAME=........" to your config.sys file, then redo setup.'
        EXIT
   END
   OTHERWISE DO
      CALL OUT_ERROR emsg.3''STRIP(LEFT(info,5))''
      info = ''
   END
   END /*select*/
END

RETURN

/*+---------------------------------------------------+
  | Subroutine to get work sub-directory information. |
  +---------------------------------------------------+*/
GET_WORK_DIR:

worksub = ''
header = 'Y'
DO WHILE worksub = ''
   /*+---------------------------------------------+
     | Display panel to get work sub-directory     |
     | Supply the user with a default PC path name.|
     +---------------------------------------------+*/
   CALL PANEL 3,msg.5,'or',msg.7'"'STRIP(LEFT(fn_worksub,50))'"'
   header = 'Y'
   PULL worksub
   worksub = STRIP(worksub)
   IF worksub = '' THEN DO
      worksub = fn_worksub
   END
   ELSE DO
      /*   remove last "\" */
      IF LENGTH(worksub) > 3 & SUBSTR(worksub,LENGTH(worksub),1) = '\'  THEN
         worksub = SUBSTR(worksub,1,LENGTH(worksub)-1)
      ELSE NOP
      curdir = DIRECTORY()          /* save current sub directory  */
      newdir = DIRECTORY(worksub)   /* set new directory  */
      IF newdir = '' THEN DO
         CALL OUT_ERROR emsg.8''STRIP(LEFT(worksub,50))''
         worksub = ''
      END
      ELSE
         worksub = newdir
      newdir = DIRECTORY(curdir)    /* reset dir. to old directory */
   END
END
/*+-------------------------------------------+
  | make sure path has the proper backslashes.|
  +-------------------------------------------+*/
IF SUBSTR(worksub,LENGTH(worksub),1) \= '\'  THEN
   worksub = worksub'\'
ELSE NOP

RETURN

/*+-----------------------------------+
  |  Subroutine to get max # of LUs   |
  +-----------------------------------+*/
GET_HOWMANY_LU:
maxluid = ''
header = 'Y'
DO WHILE maxluid = ''
   CALL PANEL  1,msg.4
   header = 'Y'
   PULL maxluid
   maxluid = STRIP(maxluid)
   SELECT
      WHEN maxluid = '' THEN DO
         CALL OUT_ERROR emsg.2
         maxluid = ''
      END
      WHEN maxluid > totallu THEN DO
         CALL OUT_ERROR emsg.2' 'maxluid
         maxluid = ''
      END
      WHEN (maxluid < 1 | maxluid > 12) THEN DO
         CALL OUT_ERROR emsg.2' 'maxluid
         maxluid = ''
      END
      OTHERWISE NOP
   END /* select */
END
RETURN

/*+-----------------------------------+
  |  Subroutine to get host LU letter |
  +-----------------------------------+*/
GETLU:
/*+----------------------------------------------+
  | Ask the user which LU s/he is logged onto.   |
  +----------------------------------------------+*/
luid = ' '
/*+----------------------------------------+
  |   determine how many LUs the user has  |
  +----------------------------------------+*/
low = WORD(luletter,1)
max = WORD(luletter,maxluid)

header = 'Y'
DO WHILE (luid < low | luid > max)
   CALL PANEL  3,msg.3'['LEFT(low,1)' - 'LEFT(max,1)']','or',msg.7'"'defaultlu'"'
   header = 'Y'
   PULL luid
   luid = STRIP(luid)
   IF luid = '' THEN
      luid = defaultlu
   ELSE NOP
   IF (luid < low | luid > max) THEN DO
      CALL OUT_ERROR emsg.3
      luid = ''
   END
   ELSE NOP
END
RETURN

/*+-----------------------------------+
  |  Subroutine to get host user id   |
  +-----------------------------------+*/
GET_USER_ID:

userid = ''
header = 'Y'
DO WHILE userid = ''
   CALL PANEL  1,msg.6
   header = 'Y'
   PULL userid
   userid = STRIP(userid)
   IF LENGTH(userid) > 8 THEN DO
      CALL OUT_ERROR emsg.13
      userid = ''
   END
   ELSE NOP
END
RETURN

/*+-------------------------------------------------+
  |  ask the user if s/he wants doc's to be printed |
  +-------------------------------------------------+*/
GET_DOC_PRINT:

   printdoc = ''
   header = 'Y'
   DO WHILE printdoc = ''
      CALL PANEL  1,msg.13
      header = 'Y'
      PULL printdoc
      PARSE UPPER VAR printdoc printdoc             /* upper case */
      printdoc = STRIP(printdoc)
      IF printdoc \= 'Y' & printdoc \= 'N' THEN DO
         CALL OUT_ERROR emsg.3
         printdoc = ''
      END
      ELSE NOP
   END

RETURN

/*+-----------------------------------+
  |  write user data file             |
  +-----------------------------------+*/
WRITE_DATAFILE:
   'ATTRIB  -R 'fn_user_data' '       /* remove read only attribute */
   'ERASE 'fn_user_data
   header = 'Y'
   CALL PANEL  1,msg.10
   nothing = LINEOUT(fn_user_data,worksub)
   pcfile = userid
   nothing = LINEOUT(fn_user_data,pcfile)
   nothing = LINEOUT(fn_user_data,maxluid)
   nothing = LINEOUT(fn_user_data,luid)
   dsnmembername = userid
   nothing = LINEOUT(fn_user_data,dsnmembername)
   sequential = 'N'
   nothing = LINEOUT(fn_user_data,sequential)
   quotes = 'Y'
   nothing = LINEOUT(fn_user_data,quotes)
   temp = "'"userid".CLIST()'"
   nothing = LINEOUT(fn_user_data,temp)
   temp = LEFT(userid,9)''LEFT('EXEC',9)''LEFT('A',4)
   nothing = LINEOUT(fn_user_data,temp)
   nothing = LINEOUT(fn_user_data) /* close the file  */
   'ATTRIB  +R 'fn_user_data' '          /* mark the file as read only */

RETURN

/*+--------------------------------------------+
  |  copy documentation and print if requested |
  +--------------------------------------------+*/
COPY_DOC:

   IF printdoc = 'Y'  THEN DO
      header = 'Y'
      CALL PANEL  1,msg.12
      'COPY xmit.doc  LPT1'
   END
   ELSE NOP

RETURN

/*+--------------------------------------------+
  |  tell the user we are finished.            |
  +--------------------------------------------+*/
COMPLETE:

   header = 'Y'
   CALL PANEL  5,msg.14,' ',msg.15,' ',msg.16

RETURN

/*+-----------------------+
  | Output error message  |
  +-----------------------+*/
OUT_ERROR:
PARSE ARG p.1
"CLS"
/* CALL BEEP 262,125 */
SAY '+'COPIES('-',70)'+'
SAY '|  'LEFT(p.1,68)'|'
SAY '+'COPIES('-',70)'+'
header = 'N'
RETURN

/*+--------------------------------------+
  | Display Panel with user information. |
  +--------------------------------------+*/
PANEL:
PARSE ARG num,p.1,p.2,p.3,p.4,p.5,p.6,p.7,p.8,p.9

IF header = 'Y' THEN DO
   "CLS"
   SAY '+'COPIES('-',70)'+'
END
ELSE NOP
SAY '|'COPIES(' ',70)'|'
DO ii=1 to num
   SAY '|'CENTER(STRIP(p.ii),70)'|'
END
SAY '|'COPIES(' ',70)'|'
SAY '+'COPIES('-',70)'+'
RETURN

/*+-----------------------------------------------+
  | Valid characters in host names                |
  +-----------------------------------------------+*/
VALID_CHAR:
PARSE ARG p.1
IF POS('~',p.1) \= 0 | POS('`',p.1) \= 0 |,
   POS('!',p.1) \= 0 | POS('%',p.1) \= 0 |,
   POS('^',p.1) \= 0 | POS('&',p.1) \= 0 |,
                       POS('(',p.1) \= 0 |,
   POS(')',p.1) \= 0 | POS('=',p.1) \= 0 |,
   POS('+',p.1) \= 0 | POS('|',p.1) \= 0 |,
   POS('\',p.1) \= 0 | POS('/',p.1) \= 0 |,
   POS('{',p.1) \= 0 | POS('}',p.1) \= 0 |,
   POS('[',p.1) \= 0 | POS(']',p.1) \= 0 |,
   POS(';',p.1) \= 0 | POS(':',p.1) \= 0 |,
   POS('<',p.1) \= 0 | POS('>',p.1) \= 0 |,
   POS(',',p.1) \= 0 | POS('?',p.1) \= 0 THEN  DO
 RETURN 1
END
ELSE NOP

RETURN 0

/*+-----------------------------------------------+
  | Information and error message table           |
  +-----------------------------------------------+*/
TABLE:
msg.1 = 'Is this your username? {Y/N} '
msg.2 = 'Please be sure that you are logged on to the proper host session.'
msg.3 = 'Which (host session) LU do you use most frequently?? '
msg.4 = "How many host LU's do you have??"
msg.5 = 'Please specify the most frequently used PC work sub-directory, '
msg.6 = 'Please give your host User Id. '
msg.7 = 'press ENTER to use '
msg.8 = 'Reading XMIT.CMD - please wait '
msg.9 = 'Writing XMIT.CMD - please wait '
msg.10 = 'Writing user data file - please wait '
msg.11 = 'Copying the install program - please wait '
msg.12 = 'Printing the Xmit Documentation - please wait '
msg.13 = 'Would you like Xmit Documentation to be printed?? {Y/N} '
msg.14 = 'The Setup program has now completed. '
msg.15 = 'You can now execute XMIT.CMD, at your will. '
msg.16 = 'Thank you for using this utility. '
/*+-------------------------------------+
  | Error message table.                |
  +-------------------------------------+*/
emsg.1 = 'The LU specified is invalid.'
emsg.2 = 'Invalid number. Please choose again.'
emsg.3 = 'Invalid letter. Please choose again.'
emsg.4 = ''
emsg.5 = ''
emsg.6 = 'Do NOT include the hard letter and colon ":". '
emsg.7 = 'The hard drive you specified does NOT exist. '
emsg.8 = 'The inputted directory does NOT exist: '
emsg.9 = ''
emsg.10 = ''
emsg.11 = ''
emsg.12 = ''
emsg.13 = 'User Id cannot be longer than 8 characters. '
RETURN
/*+-------------------------------------+
  | Music                               |
  +-------------------------------------+*/
MUSIC:
note.1 = 262
note.2 = 294
note.3 = 330
note.4 = 349
note.5 = 392
note.6 = 440
note.7 = 494
note.8 = 523

/*   call beep note.i,250 */
do i=1 to 2
   call beep note.i,125
end

return
